@@ -12,8 +12,8 @@ from runit import RunIt
 load_dotenv()
 
 CURRENT_PATH = os.path.dirname(os.path.realpath(__file__))
-HOMEDIR = os.getenv('RUNIT_HOMEDIR')
-PROJECTS_DIR = os.path.realpath(os.path.join(HOMEDIR, 'projects'))
+HOMEDIR = os.getenv('RUNIT_HOMEDIR', os.path.realpath(os.path.join(CURRENT_PATH, '..')))
+PROJECTS_DIR = os.path.join(HOMEDIR, 'projects')
 
 public = Blueprint('public', __name__)
 
